@@ -83,7 +83,7 @@ brf_findBrlNodes (xmlNode * node)
     case utdmeta:
       return 1;
     case utdbrl:
-      logMessage(LOG_DEBUG, "Processing brl node");
+      logMessage(LOU_LOG_DEBUG, "Processing brl node");
       brf_doBrlNode (node, 0);
       pop_sem_stack ();
       return 1;
@@ -125,18 +125,18 @@ brf_insertCharacters (const char *text, int length)
 static int
 brf_doDotsText (xmlNode * node)
 {
-  logMessage(LOG_DEBUG, "brf_doDotsText %s", node->content);
+  logMessage(LOU_LOG_DEBUG, "brf_doDotsText %s", node->content);
   ud->text_length = 0;
   insert_utf8 (node->content);
   if ((ud->outbuf1_len_so_far + ud->text_length) > ud->outbuf1_len)
     brf_saveBuffer ();
-  logMessage(LOG_DEBUG, "text_buffer: %s", ud->text_buffer);
+  logMessage(LOU_LOG_DEBUG, "text_buffer: %s", ud->text_buffer);
   if (!lou_dotsToChar (ud->main_braille_table, ud->text_buffer,
 		       &ud->outbuf1[ud->outbuf1_len_so_far],
 		       ud->text_length, 0))
     return 0;
-  logMessage(LOG_DEBUG, "ud->textLength %d", ud->text_length);
-  logMessage(LOG_DEBUG, "ud->outbuf1: %s", &ud->outbuf1[ud->outbuf1_len_so_far+1]);
+  logMessage(LOU_LOG_DEBUG, "ud->textLength %d", ud->text_length);
+  logMessage(LOU_LOG_DEBUG, "ud->outbuf1: %s", &ud->outbuf1[ud->outbuf1_len_so_far+1]);
   ud->outbuf1_len_so_far += ud->text_length;
   return 1;
 }
